asr.formalpolarization
======================

.. automodule:: asr.formalpolarization

   
   
   .. rubric:: Functions

   
   .. autofunction:: distance_to_non_pbc_boundary
   .. autofunction:: get_atomic_polarization_phase
   .. autofunction:: get_dipole_polarization_phase
   .. autofunction:: get_electronic_polarization_phase
   .. autofunction:: get_wavefunctions
   
   

   
   
   

   
   
   .. rubric:: Exceptions

   
   .. autoexception:: AtomsTooCloseToBoundary
   
   